/*
 * ip_resend_wakeup.c -- notify a corresponding ip_resend task about
 *                       changed network interface address.
 *
 * Copyright 2000       by Henner Eisen.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <unistd.h>
#include <stdio.h>
#include <fcntl.h>
#include <sys/socket.h>
#include <sys/un.h>



int main(int argc, char **argv)
{
	int ufd, debug=1;
	struct sockaddr_un  ua;

	if(argc != 3){
		fprintf(stderr,
			"usage: ip_resend_wakeup IP.AD.DR.ESS PF_UNIX_SOCKET\n");
		return 1;
	}

	if( (ufd=socket(PF_LOCAL,SOCK_DGRAM,0)) < 0){
		perror("error creating PF_LOCAL socket");
		return 1;
	}

	ua.sun_family = AF_LOCAL;
	strncpy(ua.sun_path,argv[2],sizeof(ua.sun_path));

	if(debug > 1) printf("ip_resend_wakeup %s %s: waiting for write\n",
			     argv[1], argv[2]);

	if( sendto(ufd, argv[1], strlen(argv[1]), 0,
		   (struct sockaddr*) &ua, sizeof(ua)) < 0){
		fprintf(stderr, "ip_resend_wakeup %s: sendto(%s) error: ",
			argv[1],argv[2]);
		perror("");
		return 1;
	}
	if(debug>0) printf("ip_resend_wakeup %s %s: done\n",argv[1],argv[2]);
	return 0;
}
